[cairo-commit] 9 commits - configure.in doc/public src/cairo.c src/cairo-font.c src/cairo.h src/cairo-image-surface.c src/cairo-pattern.c src/cairo-pdf-surface.c src/cairo-ps-surface.c src/cairo-scaled-font.c src/cairo-surface.c src/cairo-svg.h src/cairo-svg-surface.c src/cairo-win32-font.c src/cairo-win32-surface.c src/cairo-xlib-surface.c

Behdad Esfahbod behdad at kemper.freedesktop.org
Thu Jun 29 17:22:47 PDT 2006


 configure.in                  |    9 ++--
 doc/public/Makefile.am        |   11 ++++
 doc/public/cairo-sections.txt |   93 +++++++++++++++++++++++-------------------
 src/cairo-font.c              |    2 
 src/cairo-image-surface.c     |    6 ++
 src/cairo-pattern.c           |    2 
 src/cairo-pdf-surface.c       |   16 ++++---
 src/cairo-ps-surface.c        |   30 +++++++++----
 src/cairo-scaled-font.c       |   12 +++++
 src/cairo-surface.c           |   16 +++----
 src/cairo-svg-surface.c       |   36 ++++++++++------
 src/cairo-svg.h               |   13 ++++-
 src/cairo-win32-font.c        |   19 +++++++-
 src/cairo-win32-surface.c     |    3 +
 src/cairo-xlib-surface.c      |   70 +++++++++++++++++++++++++++++++
 src/cairo.c                   |   14 ++++++
 src/cairo.h                   |   38 +++++++++--------
 17 files changed, 287 insertions(+), 103 deletions(-)

New commits:
diff-tree 45ebf2d1f3c6cb4588c3bebf6acf1818eb723515 (from e5d18d7696eb9a48369b89517738dbaa101106d7)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 01:45:47 2006 +0200

    Fix an oops.

diff --git a/src/cairo-xlib-surface.c b/src/cairo-xlib-surface.c
index cffefa7..b55eca0 100644
--- a/src/cairo-xlib-surface.c
+++ b/src/cairo-xlib-surface.c
@@ -2105,8 +2105,6 @@ cairo_xlib_surface_get_display (cairo_su
     return surface->dpy;
 }
 
- * @dpy: an X Display
-
 /**
  * cairo_xlib_surface_get_drawable:
  * @surface: a #cairo_xlib_surface_t
diff-tree e5d18d7696eb9a48369b89517738dbaa101106d7 (from 6c3deb0be1b9d6db0104af02fb193849a8329133)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 01:44:55 2006 +0200

    Use $no_x in configure.in.

diff --git a/configure.in b/configure.in
index 835ee79..cb34956 100644
--- a/configure.in
+++ b/configure.in
@@ -188,15 +188,18 @@ dnl ====================================
 
 CAIRO_BACKEND_ENABLE(xlib, Xlib, xlib, XLIB_SURFACE, auto, [
   AC_PATH_XTRA
-  if test "x$X_CFLAGS$X_PRE_LIBS$X_LIBS$X_EXTRA_LIBS" = x; then
+  if test "x$no_x" = xyes; then
     use_xlib="no (requires Xlib)"
   else
     xlib_LIBS="$X_PRE_LIBS $X_LIBS -lX11 $X_EXTRA_LIBS"
     xlib_CFLAGS=$X_CFLAGS
-    _CHECK_FUNCS_WITH_FLAGS(XrmFinalize, $xlib_CFLAGS, $xlib_LIBS)
   fi
 ])
 
+if test "x$use_xlib" = xyes; then
+  _CHECK_FUNCS_WITH_FLAGS(XrmFinalize, $xlib_CFLAGS, $xlib_LIBS)
+fi
+
 CAIRO_BACKEND_ENABLE(xlib_xrender, Xlib Xrender, xlib-xrender, XLIB_XRENDER_SURFACE, auto, [
   use_xlib_xrender=$use_xlib
   if test "x$use_xlib_xrender" = xyes; then
diff-tree 6c3deb0be1b9d6db0104af02fb193849a8329133 (from 8860263c6a18a0b196e2b462a538dfc166fbea04)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 01:33:14 2006 +0200

    Minor doc syntax fixes.

diff --git a/src/cairo-surface.c b/src/cairo-surface.c
index 0be3ed2..dd349c2 100644
--- a/src/cairo-surface.c
+++ b/src/cairo-surface.c
@@ -719,7 +719,7 @@ cairo_surface_set_device_offset (cairo_s
  * @x_offset: the offset in the X direction, in device units
  * @y_offset: the offset in the Y direction, in device units
  *
- * Returns a previous device offset set by
+ * This function returns the previous device offset set by
  * cairo_surface_set_device_offset().
  *
  * Since: 1.2
diff --git a/src/cairo.h b/src/cairo.h
index f1bdce9..d2116cb 100644
--- a/src/cairo.h
+++ b/src/cairo.h
@@ -204,7 +204,7 @@ typedef enum _cairo_status {
  * @CAIRO_CONTENT_ALPHA: The surface will hold alpha content only.
  * @CAIRO_CONTENT_COLOR_ALPHA: The surface will hold color and alpha content.
  *
- * @cairo_content_t is used to describe the content that a surface will
+ * #cairo_content_t is used to describe the content that a surface will
  * contain, whether color information, alpha information (translucence
  * vs. opacity), or both.
  *
@@ -934,7 +934,7 @@ cairo_font_face_status (cairo_font_face_
  * @CAIRO_FONT_TYPE_WIN32: The font is of type Win32
  * @CAIRO_FONT_TYPE_ATSUI: The font is of type ATSUI
  *
- * @cairo_font_type_t is used to describe the type of a given font
+ * #cairo_font_type_t is used to describe the type of a given font
  * face or scaled font. The font types are also known as "font
  * backends" within cairo.
  *
@@ -1231,7 +1231,7 @@ cairo_surface_status (cairo_surface_t *s
  * @CAIRO_SURFACE_TYPE_DIRECTFB: The surface is of type directfb
  * @CAIRO_SURFACE_TYPE_SVG: The surface is of type svg
  *
- * @cairo_surface_type_t is used to describe the type of a given
+ * #cairo_surface_type_t is used to describe the type of a given
  * surface. The surface types are also known as "backends" or "surface
  * backends" within cairo.
  *
diff-tree 8860263c6a18a0b196e2b462a538dfc166fbea04 (from 6672529541e01b0da53fff279cb1f8030c931ffb)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 01:29:54 2006 +0200

    Remove CAIRO_SVG_VERSION_LAST from public header file.

diff --git a/src/cairo-svg-surface.c b/src/cairo-svg-surface.c
index 7e27787..6383a32 100644
--- a/src/cairo-svg-surface.c
+++ b/src/cairo-svg-surface.c
@@ -53,12 +53,14 @@ typedef struct cairo_svg_surface cairo_s
 
 static const int invalid_pattern_id = -1;
 
-static const cairo_svg_version_t _cairo_svg_versions[CAIRO_SVG_VERSION_LAST] =
+static const cairo_svg_version_t _cairo_svg_versions[] =
 {
     CAIRO_SVG_VERSION_1_1,
     CAIRO_SVG_VERSION_1_2
 };
 
+#define CAIRO_SVG_VERSION_LAST ((int)(sizeof (_cairo_svg_versions) / sizeof (_cairo_svg_versions[0])))
+
 static const char * _cairo_svg_version_strings[CAIRO_SVG_VERSION_LAST] =
 {
     "SVG 1.1",
@@ -317,10 +319,12 @@ cairo_svg_get_versions (cairo_svg_versio
  * cairo_svg_version_to_string:
  * @version: a version id
  *
- * Returns the string associated to given @version. This function
+ * Get the string representation of the given @version id. This function
  * will return NULL if @version isn't valid. See cairo_svg_get_versions()
  * for a way to get the list of valid version ids.
  *
+ * Return value: the string associated to given version.
+ *
  * Since: 1.2
  **/
 const char *
diff --git a/src/cairo-svg.h b/src/cairo-svg.h
index d289936..cb16fe0 100644
--- a/src/cairo-svg.h
+++ b/src/cairo-svg.h
@@ -38,10 +38,17 @@
 
 CAIRO_BEGIN_DECLS
 
+/**
+ * cairo_svg_version_t
+ * @CAIRO_SVG_VERSION_1_1: The version 1.1 of the SVG specification.
+ * @CAIRO_SVG_VERSION_1_2: The version 1.2 of the SVG specification.
+ *
+ * #cairo_svg_version_t is used to describe the version number of the SVG
+ * specification that a generated SVG file will conform to.
+ */
 typedef enum {
-    CAIRO_SVG_VERSION_1_1 = 0,
-    CAIRO_SVG_VERSION_1_2,
-    CAIRO_SVG_VERSION_LAST
+    CAIRO_SVG_VERSION_1_1,
+    CAIRO_SVG_VERSION_1_2
 } cairo_svg_version_t;
 
 cairo_public cairo_surface_t *
diff-tree 6672529541e01b0da53fff279cb1f8030c931ffb (from 66436d132772af627447a929ced3a8a18cc6915f)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 00:58:01 2006 +0200

    Hook some more symbols into docs.

diff --git a/doc/public/cairo-sections.txt b/doc/public/cairo-sections.txt
index 5215fe0..c18bc05 100644
--- a/doc/public/cairo-sections.txt
+++ b/doc/public/cairo-sections.txt
@@ -130,6 +130,9 @@ cairo_surface_get_type
 <FILE>cairo-version</FILE>
 <TITLE>Version Information</TITLE>
 CAIRO_VERSION
+CAIRO_VERSION_MAJOR
+CAIRO_VERSION_MINOR
+CAIRO_VERSION_MICRO
 CAIRO_VERSION_STRING
 CAIRO_VERSION_ENCODE
 cairo_version
diff-tree 66436d132772af627447a929ced3a8a18cc6915f (from de939f52061ba9a1c739c193e3e4f549668855cc)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Fri Jun 30 00:46:48 2006 +0200

    Update lots of docs.

diff --git a/doc/public/Makefile.am b/doc/public/Makefile.am
index 21996d2..ce815e2 100644
--- a/doc/public/Makefile.am
+++ b/doc/public/Makefile.am
@@ -45,7 +45,14 @@ IGNORE_HFILES=					\
 	cairo-scaled-font-test.h		\
 	cairo-svg-test.h			\
 	cairo-xlib-test.h			\
-	cairoint.h
+	cairoint.h				\
+	cairo-atsui.h				\
+	cairo-beos.h				\
+	cairo-directfb.h			\
+	cairo-glitz.h				\
+	cairo-quartz.h				\
+	cairo-xcb.h				\
+	cairo-xcb-xrender.h
 
 
 # CFLAGS and LDFLAGS for compiling scan program. Only needed
diff --git a/doc/public/cairo-sections.txt b/doc/public/cairo-sections.txt
index 575aa67..5215fe0 100644
--- a/doc/public/cairo-sections.txt
+++ b/doc/public/cairo-sections.txt
@@ -12,25 +12,23 @@ cairo_ft_scaled_font_unlock_face
 <FILE>cairo-win32-fonts</FILE>
 <TITLE>Win32 Fonts</TITLE>
 cairo_win32_font_face_create_for_logfontw
+cairo_win32_font_face_create_for_hfont
 cairo_win32_scaled_font_select_font
 cairo_win32_scaled_font_done_font
 cairo_win32_scaled_font_get_metrics_factor
 </SECTION>
 
 <SECTION>
-<FILE>cairo-glitz</FILE>
-<TITLE>Glitz Surfaces</TITLE>
-cairo_glitz_surface_create
-</SECTION>
-
-<SECTION>
 <FILE>cairo-image</FILE>
 <TITLE>Image Surfaces</TITLE>
 cairo_format_t
 cairo_image_surface_create
 cairo_image_surface_create_for_data
+cairo_image_surface_get_data
+cairo_image_surface_get_format
 cairo_image_surface_get_width
 cairo_image_surface_get_height
+cairo_image_surface_get_stride
 </SECTION>
 
 <SECTION>
@@ -38,7 +36,7 @@ cairo_image_surface_get_height
 <TITLE>PDF Surfaces</TITLE>
 cairo_pdf_surface_create
 cairo_pdf_surface_create_for_stream
-cairo_pdf_surface_set_dpi
+cairo_pdf_surface_set_size
 </SECTION>
 
 <SECTION>
@@ -57,40 +55,18 @@ cairo_surface_write_to_png_stream
 <TITLE>PostScript Surfaces</TITLE>
 cairo_ps_surface_create
 cairo_ps_surface_create_for_stream
-cairo_ps_surface_set_dpi
-</SECTION>
-
-<SECTION>
-<FILE>cairo-quartz</FILE>
-<TITLE>Quartz Surfaces</TITLE>
-cairo_quartz_surface_create
+cairo_ps_surface_set_size
+cairo_ps_surface_dsc_begin_setup
+cairo_ps_surface_dsc_begin_page_setup
+cairo_ps_surface_dsc_comment
 </SECTION>
 
 <SECTION>
 <FILE>cairo-win32</FILE>
 <TITLE>Win32 Surfaces</TITLE>
 cairo_win32_surface_create
-</SECTION>
-
-<SECTION>
-<FILE>cairo-beos</FILE>
-<TITLE>BeOS Surfaces</TITLE>
-cairo_beos_surface_create
-cairo_beos_surface_create_for_bitmap
-</SECTION>
-
-<SECTION>
-<FILE>cairo-xcb</FILE>
-<TITLE>XCB Surfaces</TITLE>
-cairo_xcb_surface_create
-cairo_xcb_surface_create_for_bitmap
-cairo_xcb_surface_set_size
-</SECTION>
-
-<SECTION>
-<FILE>cairo-xcb-xrender</FILE>
-<TITLE>XCB Render Surfaces</TITLE>
-cairo_xcb_surface_create_with_xrender_format
+cairo_win32_surface_create_with_dib
+cairo_win32_surface_get_dc
 </SECTION>
 
 <SECTION>
@@ -99,7 +75,14 @@ cairo_xcb_surface_create_with_xrender_fo
 cairo_xlib_surface_create
 cairo_xlib_surface_create_for_bitmap
 cairo_xlib_surface_set_size
+cairo_xlib_surface_get_display
+cairo_xlib_surface_get_screen
 cairo_xlib_surface_set_drawable
+cairo_xlib_surface_get_drawable
+cairo_xlib_surface_get_visual
+cairo_xlib_surface_get_width
+cairo_xlib_surface_get_height
+cairo_xlib_surface_get_depth
 </SECTION>
 
 <SECTION>
@@ -113,8 +96,8 @@ cairo_xlib_surface_create_with_xrender_f
 <TITLE>SVG Surfaces</TITLE>
 cairo_svg_surface_create
 cairo_svg_surface_create_for_stream
-cairo_svg_surface_set_dpi
 cairo_svg_surface_restrict_to_version
+cairo_svg_version_t
 cairo_svg_get_versions
 cairo_svg_version_to_string 
 </SECTION>
@@ -129,13 +112,18 @@ cairo_surface_destroy
 cairo_surface_finish
 cairo_surface_flush
 cairo_surface_get_font_options
+cairo_surface_get_content
 cairo_surface_set_user_data
 cairo_surface_get_user_data
 cairo_surface_mark_dirty
 cairo_surface_mark_dirty_rectangle
 cairo_surface_reference
 cairo_surface_set_device_offset
+cairo_surface_get_device_offset
+cairo_surface_set_fallback_resolution
 cairo_surface_status
+cairo_surface_type_t
+cairo_surface_get_type
 </SECTION>
 
 <SECTION>
@@ -170,6 +158,8 @@ cairo_pattern_set_filter
 cairo_pattern_get_filter
 cairo_pattern_set_matrix
 cairo_pattern_get_matrix
+cairo_pattern_type_t
+cairo_pattern_get_type
 </SECTION>
 
 <SECTION>
@@ -207,6 +197,8 @@ cairo_font_face_destroy
 cairo_font_face_status
 cairo_font_face_get_user_data
 cairo_font_face_set_user_data
+cairo_font_type_t
+cairo_font_face_get_type
 </SECTION>
 
 <SECTION>
@@ -220,7 +212,13 @@ cairo_scaled_font_status
 cairo_font_extents_t
 cairo_scaled_font_extents
 cairo_text_extents_t
+cairo_scaled_font_text_extents
 cairo_scaled_font_glyph_extents
+cairo_scaled_font_get_font_face
+cairo_scaled_font_get_font_options
+cairo_scaled_font_get_font_matrix
+cairo_scaled_font_get_ctm
+cairo_scaled_font_get_type
 </SECTION>
 
 <SECTION>
@@ -284,6 +282,7 @@ cairo_path_destroy
 cairo_append_path
 cairo_get_current_point
 cairo_new_path
+cairo_new_sub_path
 cairo_close_path
 cairo_arc
 cairo_arc_negative
@@ -315,6 +314,7 @@ cairo_show_glyphs
 cairo_get_font_face
 cairo_font_extents
 cairo_set_font_face
+cairo_set_scaled_font
 cairo_text_extents
 cairo_glyph_extents
 </SECTION>
@@ -326,10 +326,15 @@ cairo_t
 cairo_create
 cairo_reference
 cairo_destroy
+cairo_status
 cairo_save
 cairo_restore
-cairo_status
 cairo_get_target
+cairo_push_group
+cairo_push_group_with_content
+cairo_pop_group
+cairo_pop_group_to_source
+cairo_get_group_target
 cairo_set_source_rgb
 cairo_set_source_rgba
 cairo_set_source
@@ -375,6 +380,9 @@ cairo_in_stroke
 cairo_copy_page
 cairo_show_page
 <SUBSECTION Private>
+cairo_public
+CAIRO_BEGIN_DECLS
+CAIRO_END_DECLS
 cairo_current_font_extents
 cairo_get_font_extents
 cairo_current_operator
@@ -388,7 +396,6 @@ cairo_current_miter_limit
 cairo_current_matrix
 cairo_current_target_surface
 cairo_get_status
-cairo_get_status_string
 cairo_concat_matrix
 cairo_scale_font
 cairo_select_font
@@ -409,6 +416,9 @@ cairo_xlib_surface_create_for_pixmap_wit
 cairo_xlib_surface_create_for_window_with_visual
 cairo_xcb_surface_create_for_pixmap_with_visual
 cairo_xcb_surface_create_for_window_with_visual
+cairo_ps_surface_set_dpi
+cairo_pdf_surface_set_dpi
+cairo_svg_surface_set_dpi
 cairo_current_path
 cairo_current_path_flat
 cairo_get_path
@@ -424,8 +434,6 @@ cairo_surface_get_filter
 cairo_matrix_create
 cairo_matrix_destroy
 cairo_matrix_copy
-cairo_matrix_set_identity
-cairo_matrix_set_affine
 cairo_matrix_get_affine
 cairo_set_target_surface
 cairo_set_target_glitz
@@ -437,4 +445,6 @@ cairo_set_target_quartz
 cairo_set_target_win32
 cairo_set_target_xcb
 cairo_set_target_drawable
+cairo_get_status_string
+cairo_status_string
 </SECTION>
diff --git a/src/cairo-ps-surface.c b/src/cairo-ps-surface.c
index 6021306..f8915a2 100644
--- a/src/cairo-ps-surface.c
+++ b/src/cairo-ps-surface.c
@@ -773,13 +773,13 @@ cairo_ps_surface_create (const char		*fi
 
 /**
  * cairo_ps_surface_create_for_stream:
- * @write: a #cairo_write_func_t to accept the output data
- * @closure: the closure argument for @write
+ * @write_func: a #cairo_write_func_t to accept the output data
+ * @closure: the closure argument for @write_func
  * @width_in_points: width of the surface, in points (1 point == 1/72.0 inch)
  * @height_in_points: height of the surface, in points (1 point == 1/72.0 inch)
  *
  * Creates a PostScript surface of the specified size in points to be
- * written incrementally to the stream represented by @write and
+ * written incrementally to the stream represented by @write_func and
  * @closure. See cairo_ps_surface_create() for a more convenient way
  * to simply direct the PostScript output to a named file.
  *
@@ -948,23 +948,21 @@ cairo_ps_surface_set_size (cairo_surface
  *
  * <informalexample><programlisting>
  * cairo_surface_t *surface = cairo_ps_surface_create (filename, width, height);
- *
+ * ...
  * cairo_ps_surface_dsc_comment (surface, "%%Title: My excellent document");
  * cairo_ps_surface_dsc_comment (surface, "%%Copyright: Copyright (C) 2006 Cairo Lover")
- *
+ * ...
  * cairo_ps_surface_dsc_begin_setup (surface);
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *MediaColor White");
- *
+ * ...
  * cairo_ps_surface_dsc_begin_page_setup (surface);
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *PageSize A3");
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *InputSlot LargeCapacity");
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *MediaType Glossy");
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *MediaColor Blue");
- *
  * ... draw to first page here ..
- *
  * cairo_show_page (cr);
- *
+ * ...
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *PageSize A5");
  * ...
  * </programlisting></informalexample>
diff --git a/src/cairo-win32-font.c b/src/cairo-win32-font.c
index 144c3e1..39c9522 100644
--- a/src/cairo-win32-font.c
+++ b/src/cairo-win32-font.c
@@ -1415,8 +1415,9 @@ static const cairo_font_face_backend_t _
  *
  * Creates a new font for the Win32 font backend based on a
  * #LOGFONT. This font can then be used with
- * cairo_set_font_face() or cairo_font_create(). The #cairo_scaled_font_t
- * returned from cairo_font_create() is also for the Win32 backend
+ * cairo_set_font_face() or cairo_scaled_font_create().
+ * The #cairo_scaled_font_t
+ * returned from cairo_scaled_font_create() is also for the Win32 backend
  * and can be used with functions such as cairo_win32_scaled_font_select_font().
  *
  * Return value: a newly created #cairo_font_face_t. Free with
@@ -1441,6 +1442,20 @@ cairo_win32_font_face_create_for_logfont
     return &font_face->base;
 }
 
+/**
+ * cairo_win32_font_face_create_for_hfont:
+ * @font: An #HFONT structure specifying the font to use.
+ *
+ * Creates a new font for the Win32 font backend based on a
+ * #HFONT. This font can then be used with
+ * cairo_set_font_face() or cairo_scaled_font_create().
+ * The #cairo_scaled_font_t
+ * returned from cairo_scaled_font_create() is also for the Win32 backend
+ * and can be used with functions such as cairo_win32_scaled_font_select_font().
+ *
+ * Return value: a newly created #cairo_font_face_t. Free with
+ *  cairo_font_face_destroy() when you are done using it.
+ **/
 cairo_font_face_t *
 cairo_win32_font_face_create_for_hfont (HFONT font)
 {
diff --git a/src/cairo-win32-surface.c b/src/cairo-win32-surface.c
index 404dd4c..0554e43 100644
--- a/src/cairo-win32-surface.c
+++ b/src/cairo-win32-surface.c
@@ -1184,6 +1184,7 @@ cairo_win32_surface_create (HDC hdc)
  *
  * Return value: the newly created surface
  *
+ * Since: 1.2
  **/
 cairo_surface_t *
 cairo_win32_surface_create_with_dib (cairo_format_t format,
@@ -1215,6 +1216,8 @@ _cairo_surface_is_win32 (cairo_surface_t
  * Also returns NULL if the surface is not a win32 surface.
  *
  * Return value: HDC or NULL if no HDC available.
+ *
+ * Since: 1.2
  **/
 HDC
 cairo_win32_surface_get_dc (cairo_surface_t *surface)
diff --git a/src/cairo-xlib-surface.c b/src/cairo-xlib-surface.c
index 8b9d02e..cffefa7 100644
--- a/src/cairo-xlib-surface.c
+++ b/src/cairo-xlib-surface.c
@@ -2082,6 +2082,16 @@ cairo_xlib_surface_set_drawable (cairo_s
     surface->height = height;
 }
 
+/**
+ * cairo_xlib_surface_get_display:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the X Display for the underlying X Drawable.
+ *
+ * Return value: the display.
+ *
+ * Since: 1.2
+ **/
 Display *
 cairo_xlib_surface_get_display (cairo_surface_t *abstract_surface)
 {
@@ -2095,6 +2105,18 @@ cairo_xlib_surface_get_display (cairo_su
     return surface->dpy;
 }
 
+ * @dpy: an X Display
+
+/**
+ * cairo_xlib_surface_get_drawable:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the underlying X Drawable used for the surface.
+ *
+ * Return value: the drawable.
+ *
+ * Since: 1.2
+ **/
 Drawable
 cairo_xlib_surface_get_drawable (cairo_surface_t *abstract_surface)
 {
@@ -2108,6 +2130,16 @@ cairo_xlib_surface_get_drawable (cairo_s
     return surface->drawable;
 }
 
+/**
+ * cairo_xlib_surface_get_screen:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the X Screen for the underlying X Drawable.
+ *
+ * Return value: the screen.
+ *
+ * Since: 1.2
+ **/
 Screen *
 cairo_xlib_surface_get_screen (cairo_surface_t *abstract_surface)
 {
@@ -2121,6 +2153,16 @@ cairo_xlib_surface_get_screen (cairo_sur
     return surface->screen;
 }
 
+/**
+ * cairo_xlib_surface_get_visual:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the X Visual used for underlying X Drawable.
+ *
+ * Return value: the visual.
+ *
+ * Since: 1.2
+ **/
 Visual *
 cairo_xlib_surface_get_visual (cairo_surface_t *abstract_surface)
 {
@@ -2134,6 +2176,16 @@ cairo_xlib_surface_get_visual (cairo_sur
     return surface->visual;
 }
 
+/**
+ * cairo_xlib_surface_get_depth:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the number of bits used to represent each pixel value.
+ *
+ * Return value: the depth of the surface in bits.
+ *
+ * Since: 1.2
+ **/
 int
 cairo_xlib_surface_get_depth (cairo_surface_t *abstract_surface)
 {
@@ -2147,6 +2199,16 @@ cairo_xlib_surface_get_depth (cairo_surf
     return surface->depth;
 }
 
+/**
+ * cairo_xlib_surface_get_width:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the width of the X Drawable underlying the surface in pixels.
+ *
+ * Return value: the width of the surface in pixels.
+ *
+ * Since: 1.2
+ **/
 int
 cairo_xlib_surface_get_width (cairo_surface_t *abstract_surface)
 {
@@ -2160,6 +2222,16 @@ cairo_xlib_surface_get_width (cairo_surf
     return surface->width;
 }
 
+/**
+ * cairo_xlib_surface_get_height:
+ * @surface: a #cairo_xlib_surface_t
+ *
+ * Get the height of the X Drawable underlying the surface in pixels.
+ *
+ * Return value: the height of the surface in pixels.
+ *
+ * Since: 1.2
+ **/
 int
 cairo_xlib_surface_get_height (cairo_surface_t *abstract_surface)
 {
diff --git a/src/cairo.h b/src/cairo.h
index f5cdf88..f1bdce9 100644
--- a/src/cairo.h
+++ b/src/cairo.h
@@ -929,9 +929,10 @@ cairo_font_face_status (cairo_font_face_
 
 /**
  * cairo_font_type_t
- * @CAIRO_FONT_TYPE_FT: The font is of type ft
- * @CAIRO_FONT_TYPE_WIN32: The font is of type win32
- * @CAIRO_FONT_TYPE_ATSUI: The font is of type atsui
+ * @CAIRO_FONT_TYPE_TOY: The font was created using cairo's toy font api
+ * @CAIRO_FONT_TYPE_FT: The font is of type FreeType
+ * @CAIRO_FONT_TYPE_WIN32: The font is of type Win32
+ * @CAIRO_FONT_TYPE_ATSUI: The font is of type ATSUI
  *
  * @cairo_font_type_t is used to describe the type of a given font
  * face or scaled font. The font types are also known as "font
@@ -939,7 +940,7 @@ cairo_font_face_status (cairo_font_face_
  *
  * The type of a font face is determined by the function used to
  * create it, which will generally be of the form
- * cairo_<type>_font_face_create. The font face type can be queried
+ * cairo_<emphasis>type</emphasis>_font_face_create. The font face type can be queried
  * with cairo_font_face_get_type()
  *
  * The various cairo_font_face functions can be used with a font face
@@ -953,7 +954,7 @@ cairo_font_face_status (cairo_font_face_
  * fonts of any type, but some font backends also provide
  * type-specific functions that must only be called with a scaled font
  * of the appropriate type. These functions have names that begin with
- * cairo_<type>_scaled_font such as cairo_ft_scaled_font_lock_face.
+ * cairo_<emphasis>type</emphasis>_scaled_font such as cairo_ft_scaled_font_lock_face.
  *
  * The behavior of calling a type-specific function with a scaled font
  * of the wrong type is undefined.
@@ -1235,7 +1236,7 @@ cairo_surface_status (cairo_surface_t *s
  * backends" within cairo.
  *
  * The type of a surface is determined by the function used to create
- * it, which will generally be of the form cairo_<type>_surface_create,
+ * it, which will generally be of the form cairo_<emphasis>type</emphasis>_surface_create,
  * (though see cairo_surface_create_similar as well).
  *
  * The surface type can be queried with cairo_surface_get_type()
@@ -1244,7 +1245,7 @@ cairo_surface_status (cairo_surface_t *s
  * any type, but some backends also provide type-specific functions
  * that must only be called with a surface of the appropriate
  * type. These functions have names that begin with
- * cairo_<type>_surface such as cairo_image_surface_get_width().
+ * cairo_<emphasis>type</emphasis>_surface such as cairo_image_surface_get_width().
  *
  * The behavior of calling a type-specific function with a surface of
  * the wrong type is undefined.
@@ -1430,7 +1431,6 @@ cairo_pattern_status (cairo_pattern_t *p
 
 /**
  * cairo_pattern_type_t
-
  * @CAIRO_PATTERN_TYPE_SOLID: The pattern is a solid (uniform)
  * color. It may be opaque or translucent.
  * @CAIRO_PATTERN_TYPE_SURFACE: The pattern is a based on a surface (an image).
@@ -1567,12 +1567,10 @@ cairo_matrix_multiply (cairo_matrix_t	  
 		       const cairo_matrix_t *a,
 		       const cairo_matrix_t *b);
 
-/* XXX: Need a new name here perhaps. */
 cairo_public void
 cairo_matrix_transform_distance (const cairo_matrix_t *matrix,
 				 double *dx, double *dy);
 
-/* XXX: Need a new name here perhaps. */
 cairo_public void
 cairo_matrix_transform_point (const cairo_matrix_t *matrix,
 			      double *x, double *y);
diff-tree de939f52061ba9a1c739c193e3e4f549668855cc (from 647ca37ca3d4b1954f7400deeeaaf245b5c90e69)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Thu Jun 29 18:54:02 2006 +0200

    Require gtk-doc 1.6, and make it ignore cairo_public and cairo_private
    
    decorators.

diff --git a/configure.in b/configure.in
index 15c2e42..835ee79 100644
--- a/configure.in
+++ b/configure.in
@@ -530,7 +530,7 @@ AC_SUBST(CAIRO_LIBS)
 dnl ===========================================================================
 dnl Check for gtk-doc and docbook
 
-GTK_DOC_CHECK([1.3])
+GTK_DOC_CHECK([1.6])
 
 dnl ===========================================================================
 dnl Check for recent pkg-config which supports Requires.private
diff --git a/doc/public/Makefile.am b/doc/public/Makefile.am
index 0899e8d..21996d2 100644
--- a/doc/public/Makefile.am
+++ b/doc/public/Makefile.am
@@ -9,7 +9,7 @@ DOC_MODULE=cairo
 DOC_MAIN_SGML_FILE=cairo-docs.xml
 
 # Extra options to supply to gtkdoc-scan
-SCAN_OPTIONS=--deprecated-guards="CAIRO_DISABLE_DEPRECATED"
+SCAN_OPTIONS=--deprecated-guards="CAIRO_DISABLE_DEPRECATED" --ignore-decorators="cairo_public|cairo_private"
 
 # The directory containing the source code. Relative to $(srcdir)
 DOC_SOURCE_DIR=../../src
diff-tree 647ca37ca3d4b1954f7400deeeaaf245b5c90e69 (from 320ce67d630e4aac1f0007982aef27c831b04b66)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Thu Jun 29 18:47:35 2006 +0200

    Mark enum additions as "Since 1.2" too.

diff --git a/src/cairo.h b/src/cairo.h
index bf49069..f5cdf88 100644
--- a/src/cairo.h
+++ b/src/cairo.h
@@ -167,7 +167,7 @@ typedef struct _cairo_user_data_key {
  * @CAIRO_STATUS_INVALID_VISUAL: invalid value for an input Visual*
  * @CAIRO_STATUS_FILE_NOT_FOUND: file not found
  * @CAIRO_STATUS_INVALID_DASH: invalid value for a dash setting
- * @CAIRO_STATUS_INVALID_DSC_COMMENT: invalid value for a DSC comment
+ * @CAIRO_STATUS_INVALID_DSC_COMMENT: invalid value for a DSC comment (Since 1.2)
  *
  * #cairo_status_t is used to indicate errors that can occur when
  * using Cairo. In some cases it is returned directly by functions.
@@ -957,6 +957,8 @@ cairo_font_face_status (cairo_font_face_
  *
  * The behavior of calling a type-specific function with a scaled font
  * of the wrong type is undefined.
+ *
+ * Since: 1.2
  */
 typedef enum _cairo_font_type {
     CAIRO_FONT_TYPE_TOY,
@@ -1246,6 +1248,8 @@ cairo_surface_status (cairo_surface_t *s
  *
  * The behavior of calling a type-specific function with a surface of
  * the wrong type is undefined.
+ *
+ * Since: 1.2
  */
 typedef enum _cairo_surface_type {
     CAIRO_SURFACE_TYPE_IMAGE,
@@ -1344,7 +1348,7 @@ cairo_surface_set_fallback_resolution (c
  *   machine the first pixel is in the least-significant bit.
  * @CAIRO_FORMAT_RGB16_565: each pixel is a 16-bit quantity,
  *   with red in the upper 5 bits, then green in the next 6,
- *   then blue in the lowest 5 bits.
+ *   then blue in the lowest 5 bits. (Since 1.2)
  *
  * #cairo_format_t is used to identify the memory format of
  * image data.
@@ -1433,7 +1437,7 @@ cairo_pattern_status (cairo_pattern_t *p
  * @CAIRO_PATTERN_TYPE_LINEAR: The pattern is a linear gradient.
  * @CAIRO_PATTERN_TYPE_RADIAL: The pattern is a radial gradient.
  *
- * @cairo_pattern_type_t us used to describe the type of a given pattern.
+ * #cairo_pattern_type_t is used to describe the type of a given pattern.
  *
  * The type of a pattern is determined by the function used to create
  * it. The cairo_pattern_create_rgb() and cairo_pattern_create_rgba()
@@ -1450,6 +1454,8 @@ cairo_pattern_status (cairo_pattern_t *p
  * cairo_pattern_add_color_stop_rgba() which must only be called with
  * gradient patterns (either LINEAR or RADIAL). Otherwise the pattern
  * will be shutdown and put into an error state.
+ *
+ * Since: 1.2
  */
 typedef enum _cairo_pattern_type {
     CAIRO_PATTERN_TYPE_SOLID,
@@ -1488,7 +1494,7 @@ cairo_pattern_get_matrix (cairo_pattern_
  * @CAIRO_EXTEND_REFLECT: the pattern is tiled by reflecting
  *   at the edges
  * @CAIRO_EXTEND_PAD: pixels outside of the pattern copy
- *   the closest pixel from the source (since cairo 1.2)
+ *   the closest pixel from the source (Since 1.2)
  *
  * #cairo_extend_t is used to describe how the area outside
  * of a pattern will be drawn.
diff-tree 320ce67d630e4aac1f0007982aef27c831b04b66 (from bd92eb7f3c58fdcbe05f67b9a879798246c616bc)
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Thu Jun 29 18:36:53 2006 +0200

    Add "Since: 1.2" to docs for most new API functions.

diff --git a/src/cairo-font.c b/src/cairo-font.c
index fb475c3..5ef8b6c 100644
--- a/src/cairo-font.c
+++ b/src/cairo-font.c
@@ -135,6 +135,8 @@ cairo_font_face_destroy (cairo_font_face
  * @font_face: a #cairo_font_face_t
  *
  * Return value: The type of @font_face. See #cairo_font_type_t.
+ *
+ * Since: 1.2
  **/
 cairo_font_type_t
 cairo_font_face_get_type (cairo_font_face_t *font_face)
diff --git a/src/cairo-image-surface.c b/src/cairo-image-surface.c
index bddf6c1..8957e4c 100644
--- a/src/cairo-image-surface.c
+++ b/src/cairo-image-surface.c
@@ -364,6 +364,8 @@ _cairo_image_surface_create_for_data_wit
  *
  * Return value: a pointer to the image data of this surface or NULL
  * if @surface is not an image surface.
+ *
+ * Since: 1.2
  **/
 unsigned char *
 cairo_image_surface_get_data (cairo_surface_t *surface)
@@ -385,6 +387,8 @@ cairo_image_surface_get_data (cairo_surf
  * Get the format of the surface.
  *
  * Return value: the format of the surface
+ *
+ * Since: 1.2
  **/
 cairo_format_t
 cairo_image_surface_get_format (cairo_surface_t *surface)
@@ -451,6 +455,8 @@ cairo_image_surface_get_height (cairo_su
  * @surface is not an image surface). The stride is the distance in
  * bytes from the beginning of one row of the image data to the
  * beginning of the next row.
+ *
+ * Since: 1.2
  **/
 int
 cairo_image_surface_get_stride (cairo_surface_t *surface)
diff --git a/src/cairo-pattern.c b/src/cairo-pattern.c
index c8f4353..1a62c66 100644
--- a/src/cairo-pattern.c
+++ b/src/cairo-pattern.c
@@ -529,6 +529,8 @@ cairo_pattern_reference (cairo_pattern_t
  * @pattern: a #cairo_pattern_t
  *
  * Return value: The type of @pattern. See #cairo_pattern_type_t.
+ *
+ * Since: 1.2
  **/
 cairo_pattern_type_t
 cairo_pattern_get_type (cairo_pattern_t *pattern)
diff --git a/src/cairo-pdf-surface.c b/src/cairo-pdf-surface.c
index 8e1192f..2bc349c 100644
--- a/src/cairo-pdf-surface.c
+++ b/src/cairo-pdf-surface.c
@@ -320,6 +320,8 @@ _cairo_pdf_surface_create_for_stream_int
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  */
 cairo_surface_t *
 cairo_pdf_surface_create_for_stream (cairo_write_func_t		 write,
@@ -358,6 +360,8 @@ cairo_pdf_surface_create_for_stream (cai
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  **/
 cairo_surface_t *
 cairo_pdf_surface_create (const char		*filename,
@@ -422,6 +426,8 @@ _extract_pdf_surface (cairo_surface_t		 
  * this is to call this function immediately after creating the
  * surface or immediately after completing a page with either
  * cairo_show_page() or cairo_copy_page().
+ *
+ * Since: 1.2
  **/
 void
 cairo_pdf_surface_set_size (cairo_surface_t	*surface,
diff --git a/src/cairo-ps-surface.c b/src/cairo-ps-surface.c
index 9446610..6021306 100644
--- a/src/cairo-ps-surface.c
+++ b/src/cairo-ps-surface.c
@@ -748,6 +748,8 @@ _cairo_ps_surface_create_for_stream_inte
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  **/
 cairo_surface_t *
 cairo_ps_surface_create (const char		*filename,
@@ -791,6 +793,8 @@ cairo_ps_surface_create (const char		*fi
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  */
 cairo_surface_t *
 cairo_ps_surface_create_for_stream (cairo_write_func_t	write_func,
@@ -856,6 +860,8 @@ _extract_ps_surface (cairo_surface_t	 *s
  * this is to call this function immediately after creating the
  * surface or immediately after completing a page with either
  * cairo_show_page() or cairo_copy_page().
+ *
+ * Since: 1.2
  **/
 void
 cairo_ps_surface_set_size (cairo_surface_t	*surface,
@@ -962,6 +968,8 @@ cairo_ps_surface_set_size (cairo_surface
  * cairo_ps_surface_dsc_comment (surface, "%%IncludeFeature: *PageSize A5");
  * ...
  * </programlisting></informalexample>
+ *
+ * Since: 1.2
  **/
 void
 cairo_ps_surface_dsc_comment (cairo_surface_t	*surface,
@@ -1016,6 +1024,8 @@ cairo_ps_surface_dsc_comment (cairo_surf
  * and before any drawing is performed to the surface.
  *
  * See cairo_ps_surface_dsc_comment() for more details.
+ *
+ * Since: 1.2
  **/
 void
 cairo_ps_surface_dsc_begin_setup (cairo_surface_t *surface)
@@ -1036,7 +1046,7 @@ cairo_ps_surface_dsc_begin_setup (cairo_
 }
 
 /**
- * cairo_ps_surface_dsc_begin_setup:
+ * cairo_ps_surface_dsc_begin_page_setup:
  * @surface: a PostScript cairo_surface_t
  *
  * This function indicates that subsequent calls to
@@ -1049,6 +1059,8 @@ cairo_ps_surface_dsc_begin_setup (cairo_
  * performed to the surface.
  *
  * See cairo_ps_surface_dsc_comment() for more details.
+ *
+ * Since: 1.2
  **/
 void
 cairo_ps_surface_dsc_begin_page_setup (cairo_surface_t *surface)
diff --git a/src/cairo-scaled-font.c b/src/cairo-scaled-font.c
index 0defd32..491189f 100644
--- a/src/cairo-scaled-font.c
+++ b/src/cairo-scaled-font.c
@@ -124,6 +124,8 @@ _cairo_scaled_font_set_error (cairo_scal
  * @scaled_font: a #cairo_scaled_font_t
  *
  * Return value: The type of @scaled_font. See #cairo_font_type_t.
+ *
+ * Since: 1.2
  **/
 cairo_font_type_t
 cairo_scaled_font_get_type (cairo_scaled_font_t *scaled_font)
@@ -643,6 +645,8 @@ cairo_scaled_font_extents (cairo_scaled_
  * characters. In particular, trailing whitespace characters are
  * likely to not affect the size of the rectangle, though they will
  * affect the x_advance and y_advance values.
+ *
+ * Since: 1.2
  **/
 void
 cairo_scaled_font_text_extents (cairo_scaled_font_t   *scaled_font,
@@ -1296,6 +1300,8 @@ _cairo_scaled_glyph_lookup (cairo_scaled
  *
  * Return value: The #cairo_font_face_t with which @scaled_font was
  * created.
+ *
+ * Since: 1.2
  **/
 cairo_font_face_t *
 cairo_scaled_font_get_font_face (cairo_scaled_font_t *scaled_font)
@@ -1313,6 +1319,8 @@ cairo_scaled_font_get_font_face (cairo_s
  *
  * Stores the font matrix with which @scaled_font was created into
  * @matrix.
+ *
+ * Since: 1.2
  **/
 void
 cairo_scaled_font_get_font_matrix (cairo_scaled_font_t	*scaled_font,
@@ -1332,6 +1340,8 @@ cairo_scaled_font_get_font_matrix (cairo
  * @ctm: return value for the CTM
  *
  * Stores the CTM with which @scaled_font was created into @ctm.
+ *
+ * Since: 1.2
  **/
 void
 cairo_scaled_font_get_ctm (cairo_scaled_font_t	*scaled_font,
@@ -1352,6 +1362,8 @@ cairo_scaled_font_get_ctm (cairo_scaled_
  *
  * Stores the font options with which @scaled_font was created into
  * @ctm.
+ *
+ * Since: 1.2
  **/
 void
 cairo_scaled_font_get_font_options (cairo_scaled_font_t		*scaled_font,
diff --git a/src/cairo-surface.c b/src/cairo-surface.c
index 51c1bcc..0be3ed2 100644
--- a/src/cairo-surface.c
+++ b/src/cairo-surface.c
@@ -158,6 +158,8 @@ _cairo_surface_set_error (cairo_surface_
  * @surface: a #cairo_surface_t
  *
  * Return value: The type of @surface. See #cairo_surface_type_t.
+ *
+ * Since: 1.2
  **/
 cairo_surface_type_t
 cairo_surface_get_type (cairo_surface_t *surface)
@@ -176,6 +178,8 @@ cairo_surface_get_type (cairo_surface_t 
  * Return value: The content type of @surface which indicates whether
  * the surface contains color and/or alpha information. See
  * #cairo_content_t.
+ *
+ * Since: 1.2
  **/
 cairo_content_t
 cairo_surface_get_content (cairo_surface_t *surface)
@@ -718,6 +722,7 @@ cairo_surface_set_device_offset (cairo_s
  * Returns a previous device offset set by
  * cairo_surface_set_device_offset().
  *
+ * Since: 1.2
  **/
 void
 cairo_surface_get_device_offset (cairo_surface_t *surface,
@@ -755,6 +760,8 @@ cairo_surface_get_device_offset (cairo_s
  * completing a page (with cairo_show_page() or cairo_copy_page()) so
  * there is currently no way to have more than one fallback resolution
  * in effect on a single page.
+ *
+ * Since: 1.2
  **/
 void
 cairo_surface_set_fallback_resolution (cairo_surface_t	*surface,
@@ -764,13 +771,6 @@ cairo_surface_set_fallback_resolution (c
     surface->x_fallback_resolution = x_pixels_per_inch;
     surface->y_fallback_resolution = y_pixels_per_inch;
 }
-/* XXX: Add symbols for old, deprecated names to eas GTK+ migration
- * pain. This is a transition strategy for prior to 1.2. These
- * aliases should be dropped before the major release.
- */
-CAIRO_FUNCTION_ALIAS(cairo_pdf_surface_set_dpi, cairo_surface_set_fallback_resolution);
-CAIRO_FUNCTION_ALIAS(cairo_ps_surface_set_dpi, cairo_surface_set_fallback_resolution);
-CAIRO_FUNCTION_ALIAS(cairo_svg_surface_set_dpi, cairo_surface_set_fallback_resolution);
 
 cairo_bool_t
 _cairo_surface_has_device_transform (cairo_surface_t *surface)
diff --git a/src/cairo-svg-surface.c b/src/cairo-svg-surface.c
index ff47236..95de094 100644
--- a/src/cairo-svg-surface.c
+++ b/src/cairo-svg-surface.c
@@ -171,6 +171,8 @@ static const cairo_paginated_surface_bac
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  */
 cairo_surface_t *
 cairo_svg_surface_create_for_stream (cairo_write_func_t		 write,
@@ -207,8 +209,9 @@ cairo_svg_surface_create_for_stream (cai
  * This function always returns a valid pointer, but it will return a
  * pointer to a "nil" surface if an error such as out of memory
  * occurs. You can use cairo_surface_status() to check for this.
+ *
+ * Since: 1.2
  **/
-
 cairo_surface_t *
 cairo_svg_surface_create (const char	*filename,
 			  double	 width,
@@ -268,8 +271,9 @@ _extract_svg_surface (cairo_surface_t		 
  * have been performed on the given surface. The simplest way to do
  * this is to call this function immediately after creating the
  * surface.
+ *
+ * Since: 1.2
  **/
-
 void
 cairo_svg_surface_restrict_to_version (cairo_surface_t 		*abstract_surface,
 				       cairo_svg_version_t  	 version)
@@ -295,8 +299,9 @@ cairo_svg_surface_restrict_to_version (c
  *
  * Returns the list of supported versions. See
  * cairo_svg_surface_restrict_to_version().
+ *
+ * Since: 1.2
  **/
-
 void
 cairo_svg_get_versions (cairo_svg_version_t const	**versions,
                         int                     	 *num_versions)
@@ -315,8 +320,9 @@ cairo_svg_get_versions (cairo_svg_versio
  * Returns the string associated to given @version. This function
  * will return NULL if @version isn't valid. See cairo_svg_get_versions()
  * for a way to get the list of valid version ids.
+ *
+ * Since: 1.2
  **/
-
 const char *
 cairo_svg_version_to_string (cairo_svg_version_t version)
 {
diff --git a/src/cairo.c b/src/cairo.c
index 9b4154a..4d005ba 100644
--- a/src/cairo.c
+++ b/src/cairo.c
@@ -371,6 +371,8 @@ slim_hidden_def(cairo_restore);
  * cairo_pop_group_to_source (cr);
  * cairo_paint_with_alpha (cr, alpha);
  * </programlisting></informalexample>
+ *
+ * Since: 1.2
  */
 void
 cairo_push_group (cairo_t *cr)
@@ -395,6 +397,8 @@ slim_hidden_def(cairo_push_group);
  * control this content type is the only distinction between this
  * function and cairo_push_group() which you should see for a more
  * detailed description of group rendering.
+ *
+ * Since: 1.2
  */
 void
 cairo_push_group_with_content (cairo_t *cr, cairo_content_t content)
@@ -458,6 +462,8 @@ slim_hidden_def(cairo_push_group_with_co
  * results of all drawing operations performed to the group. The
  * caller owns the returned object and should call
  * cairo_pattern_destroy() when finished with it.
+ *
+ * Since: 1.2
  **/
 cairo_pattern_t *
 cairo_pop_group (cairo_t *cr)
@@ -525,6 +531,8 @@ slim_hidden_def(cairo_pop_group);
  * call to cairo_save() by the push_group function), so that any
  * changes to the graphics state will not be visible outside the
  * group.
+ *
+ * Since: 1.2
  **/
 void
 cairo_pop_group_to_source (cairo_t *cr)
@@ -1219,6 +1227,8 @@ slim_hidden_def(cairo_move_to);
  * makes things easier as it is no longer necessary to manually
  * compute the arc's initial coordinates for a call to
  * cairo_move_to().
+ *
+ * Since: 1.2
  **/
 void
 cairo_new_sub_path (cairo_t *cr)
@@ -2264,6 +2274,8 @@ cairo_get_font_options (cairo_t         
  * some translation, the current CTM of the #cairo_t should be the
  * same as that of the #cairo_scaled_font_t, which can be accessed
  * using cairo_scaled_font_get_ctm().
+ *
+ * Since: 1.2
  **/
 void
 cairo_set_scaled_font (cairo_t                   *cr,
@@ -2736,6 +2748,8 @@ cairo_get_target (cairo_t *cr)
  * Return value: the target group surface, or NULL if none.  This
  * object is owned by cairo. To keep a reference to it, you must call
  * cairo_surface_reference().
+ *
+ * Since: 1.2
  **/
 cairo_surface_t *
 cairo_get_group_target (cairo_t *cr)


More information about the cairo-commit mailing list
diff --git a/src/cairo-pdf-surface.c b/src/cairo-pdf-surface.c
index 2bc349c..663097f 100644
--- a/src/cairo-pdf-surface.c
+++ b/src/cairo-pdf-surface.c
@@ -305,13 +305,13 @@ _cairo_pdf_surface_create_for_stream_int
 
 /**
  * cairo_pdf_surface_create_for_stream:
  * @write: a #cairo_write_func_t to accept the output data
  * @closure: the closure argument for @write
  * @width_in_points: width of the surface, in points (1 point == 1/72.0 inch)
  * @height_in_points: height of the surface, in points (1 point == 1/72.0 inch)
  *
  * Creates a PDF surface of the specified size in points to be written
  * incrementally to the stream represented by @write and @closure.
  *
  * Return value: a pointer to the newly created surface. The caller
  * owns the surface and should call cairo_surface_destroy when done
@@ -324,7 +324,7 @@ _cairo_pdf_surface_create_for_stream_int
  * Since: 1.2
  */
 cairo_surface_t *
-cairo_pdf_surface_create_for_stream (cairo_write_func_t		 write,
+cairo_pdf_surface_create_for_stream (cairo_write_func_t		 write_func,
 				     void			*closure,
 				     double			 width_in_points,
 				     double			 height_in_points)
@@ -332,7 +332,7 @@ cairo_pdf_surface_create_for_stream (cai
     cairo_status_t status;
     cairo_output_stream_t *output;
 
-    output = _cairo_output_stream_create (write, NULL, closure);
+    output = _cairo_output_stream_create (write_func, NULL, closure);
     status = _cairo_output_stream_get_status (output);
     if (status) {
 	_cairo_error (status);
@@ -305,13 +305,13 @@ _cairo_pdf_surface_create_for_stream_int
 /**
  * cairo_pdf_surface_create_for_stream:
- * @write: a #cairo_write_func_t to accept the output data
- * @closure: the closure argument for @write
+ * @write_func: a #cairo_write_func_t to accept the output data
+ * @closure: the closure argument for @write_func
  * @width_in_points: width of the surface, in points (1 point == 1/72.0 inch)
  * @height_in_points: height of the surface, in points (1 point == 1/72.0 inch)
@@ -305,13 +305,13 @@ _cairo_pdf_surface_create_for_stream_int
  *
  * Creates a PDF surface of the specified size in points to be written
- * incrementally to the stream represented by @write and @closure.
+ * incrementally to the stream represented by @write_func and @closure.
  *
  * Return value: a pointer to the newly created surface. The caller
diff --git a/src/cairo-svg-surface.c b/src/cairo-svg-surface.c
index 95de094..7e27787 100644
--- a/src/cairo-svg-surface.c
+++ b/src/cairo-svg-surface.c
@@ -156,13 +156,13 @@ static const cairo_paginated_surface_bac
 
 /**
  * cairo_svg_surface_create_for_stream:
  * @write: a #cairo_write_func_t to accept the output data
  * @closure: the closure argument for @write
  * @width_in_points: width of the surface, in points (1 point == 1/72.0 inch)
  * @height_in_points: height of the surface, in points (1 point == 1/72.0 inch)
  *
  * Creates a SVG surface of the specified size in points to be written
  * incrementally to the stream represented by @write and @closure.
  *
  * Return value: a pointer to the newly created surface. The caller
  * owns the surface and should call cairo_surface_destroy when done
@@ -175,7 +175,7 @@ static const cairo_paginated_surface_bac
  * Since: 1.2
  */
 cairo_surface_t *
-cairo_svg_surface_create_for_stream (cairo_write_func_t		 write,
+cairo_svg_surface_create_for_stream (cairo_write_func_t		 write_func,
 				     void			*closure,
 				     double			 width,
 				     double			 height)
@@ -183,7 +183,7 @@ cairo_svg_surface_create_for_stream (cai
     cairo_status_t status;
     cairo_output_stream_t *stream;
 
-    stream = _cairo_output_stream_create (write, NULL, closure);
+    stream = _cairo_output_stream_create (write_func, NULL, closure);
     status = _cairo_output_stream_get_status (stream);
     if (status) {
 	_cairo_error (status);
@@ -294,10 +294,10 @@ cairo_svg_surface_restrict_to_version (c
 
 /**
  * cairo_svg_get_versions:
- * @version: supported version list
+ * @versions: supported version list
  * @num_versions: list length
  *
- * Returns the list of supported versions. See
+ * Used to retrieve the list of supported versions. See
  * cairo_svg_surface_restrict_to_version().
  *
  * Since: 1.2
@@ -156,13 +156,13 @@ static const cairo_paginated_surface_bac
 /**
  * cairo_svg_surface_create_for_stream:
- * @write: a #cairo_write_func_t to accept the output data
- * @closure: the closure argument for @write
+ * @write_func: a #cairo_write_func_t to accept the output data
+ * @closure: the closure argument for @write_func
  * @width_in_points: width of the surface, in points (1 point == 1/72.0 inch)
  * @height_in_points: height of the surface, in points (1 point == 1/72.0 inch)
@@ -156,13 +156,13 @@ static const cairo_paginated_surface_bac
  *
  * Creates a SVG surface of the specified size in points to be written
- * incrementally to the stream represented by @write and @closure.
+ * incrementally to the stream represented by @write_func and @closure.
  *
  * Return value: a pointer to the newly created surface. The caller